# Welcome to VRProt's documentation!

**VRProt**
The main purpose of this project is to serve as an easy to use pipeline to facilitate the processing of protein structures for presentation on the [VRNetzer](https://github.com/menchelab/VRNetzer). It is mainly used in a the [ProteinStructureFetch Extension](https://github.com/menchelab/ProteinStructureFetch) an extension for the [VRNetzer](https://github.com/menchelab/VRNetzer) to visualize protein structures in virtual reality.

For everyone who wants to analyze their own protein structures, with your desired highlighting and coloring, this project is the right place to start. For easy usage of this project, we provide a one file executable which allows to use the program without further installation of python and any dependencies. Nevertheless, a [ChimeraX](https://www.cgl.ucsf.edu/chimerax/download.html) installation is mandatory to use the full potential of this project.
Without [ChimeraX](https://www.cgl.ucsf.edu/chimerax/download.html) this software only provides a fetcher with which you can easily fetch PDB files from the [AlphaFold Database](https://alphafold.ebi.ac.uk/) as well as some converter functions.

```{eval-rst}
.. toctree::
   :maxdepth: 2
   :caption: Contents:

```

# Indices and tables

[Index](index)

[Module Index](py-modindex)

[Search Page](search)

## Contents

```{eval-rst}
.. toctree::

   usage
   vrprot
```

## Citation

Please cite our work if you use VRProt.

```{note}


@software{VRProt2022,
author = {Oblau, Till Pascal and Fischer, Felix},
title = {{VRProt}: {A} Libary for preparing protein structure point clouds},
url = {https://VRProt.org/},
version = {1.0.0},
year = {2022},
}
```
